@@ -16,8 +16,7 @@ CHUNK_SIZE = 1024*256 # 256 KB
 
 def video_key(video):
     bitrate = 0
-
-    if "videoBitrate" in video:
+    if video.find("videoBitrate") is not None:
         bitrate = int(video.videoBitrate.text)
 
     return (
